#[repr(transparent)]pub struct BrowserActionRequest(pub usize);Expand description
Represents actions requested by the Forms Browser in response to user interactions.
Tuple Fields
0: usizeImplementations
Sourceimpl BrowserActionRequest
impl BrowserActionRequest
Sourcepub const NONE: BrowserActionRequest
pub const NONE: BrowserActionRequest
No special behavior is taken by the Forms Browser.
Sourcepub const RESET: BrowserActionRequest
pub const RESET: BrowserActionRequest
The Forms Browser will exit and request the platform to reset.
Sourcepub const SUBMIT: BrowserActionRequest
pub const SUBMIT: BrowserActionRequest
The Forms Browser will save all modified question values to storage and exit.
Sourcepub const EXIT: BrowserActionRequest
pub const EXIT: BrowserActionRequest
The Forms Browser will discard all modified question values and exit.
Sourcepub const FORM_SUBMIT_EXIT: BrowserActionRequest
pub const FORM_SUBMIT_EXIT: BrowserActionRequest
The Forms Browser will write all modified question values on the selected form to storage and exit the form.
Sourcepub const FORM_DISCARD_EXIT: BrowserActionRequest
pub const FORM_DISCARD_EXIT: BrowserActionRequest
The Forms Browser will discard the modified question values on the selected form and exit the form.
Sourcepub const FORM_APPLY: BrowserActionRequest
pub const FORM_APPLY: BrowserActionRequest
The Forms Browser will write all modified current question values on the selected form to storage.
Sourcepub const FORM_DISCARD: BrowserActionRequest
pub const FORM_DISCARD: BrowserActionRequest
The Forms Browser will discard the current question values on the selected form and replace them with the original values.
Sourcepub const RECONNECT: BrowserActionRequest
pub const RECONNECT: BrowserActionRequest
The user performed a hardware or software configuration change, requiring controller reconnection.
The Forms Browser calls DisconnectController() followed by ConnectController().
Sourcepub const QUESTION_APPLY: BrowserActionRequest
pub const QUESTION_APPLY: BrowserActionRequest
The Forms Browser will write the current modified question value on the selected form to storage.